# pymirc
general python KUL MIRC imaging routines

## authors
georg.schramm@kuleuven.be, jeroen.bertels@kuleuven.be, tom.eelbode@kuleuven.be, siri.willems@kuleuven.be

## Purpose
pymirc is a collection of common python imaging routines
(fileio, transformations, ...) developed and used in
the medical imaging research center of KU Leuven.

## Requirements
see setup.py 

## Installation from pypi
To install the package from pypi simple run
```
pip install pymirc
```

## (optional) use of modules for tensorflow
In case you want to use our tensorflow metrics and loss functions
(tf_losses.py and tf_metrics.py), you also have to tensorflow via
```
pip install tensorflow
```

## Getting started
The examples subdirectory contains minimal examples 
on how to use the most important functions.

